ImageHelper class

Constructors

ImageHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

imageProviderFor(String path) ImageProvider<Object>?
Returns an ImageProvider from URL or file path
pickImageFromCamera() Future<File?>
Picks an image from camera
pickImageFromGallery() Future<File?>