StaticStockPrefs class

Constructors

StaticStockPrefs()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

addRecord(StaticStockRecord record) Future<void>
Add single record
clear() Future<void>
Clear all
getList() Future<List<StaticStockRecord>>
Get full list
getListByLocation(String location) Future<List<StaticStockRecord>>
removeById(String id) Future<void>
Remove record by id
saveList(List<StaticStockRecord> newList) Future<void>
Save full list