TaskAssignment class
Constructors
Properties
- completedDate ↔ DateTime?
-
getter/setter pair
- dateAdd ↔ DateTime?
-
getter/setter pair
- dateEdit ↔ DateTime?
-
getter/setter pair
- delegationGroupRegister ↔ DelegationGroupRegister?
-
getter/setter pair
- description ↔ String?
-
getter/setter pair
- dueDate ↔ DateTime?
-
getter/setter pair
- employeeAdd ↔ Employee?
-
getter/setter pair
- employeeEdit ↔ Employee?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate ↔ DateTime?
-
getter/setter pair
- task ↔ Task?
-
getter/setter pair
- taskAssignmentId ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited