MessageCacheService class

Constructors

MessageCacheService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearCache() Future<void>
Optional: Clear cache
clearCacheFile() Future<void>
loadMessagesFromCache() Future<List<Message>>
Load messages from cache
saveMessagesToCache(List<Message> messages) Future<void>
Save messages to cache