GrpcClientFactory class

Constructors

GrpcClientFactory({required String host, required int port, required bool userTls, required TokenProvider? tokenProvider})

Properties

hashCode int
The hash code for this object.
no setterinherited
host String
final
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenProvider TokenProvider?
final
userTls bool
final

Methods

callOptions() Future<CallOptions>
createChanel() → ClientChannel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited