UploadItem class

Constructors

UploadItem({required String conversationId, required String senderId, File? file, required FileCategory type, String? content, double progress = 0.0, bool isUploading = true, bool isFailed = false})

Properties

content String?
final
conversationId String
final
file File?
final
hashCode int
The hash code for this object.
no setterinherited
isFailed bool
getter/setter pair
isUploading bool
getter/setter pair
progress double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId String
final
type FileCategory
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited