LiveSubscriber class

Constructors

LiveSubscriber(GrpcClientFactory _factory)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start({List<String> deviceIds = const [], List<String> employeeIds = const [], void onUpdate(LiveUpdate)?}) Future<void>
stop() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited