AccountPayable class

Constructors

AccountPayable({Suppliers? suppliers, bool? supplierGeneralJournalEntry, bool? applyDebitNote, bool? recordRefundFromSupplier, bool? viewOutstandingBills, bool? viewBillRegister, APEnquiries? apEnquiries})

Properties

apEnquiries APEnquiries?
getter/setter pair
applyDebitNote bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
recordRefundFromSupplier bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supplierGeneralJournalEntry bool?
getter/setter pair
suppliers Suppliers?
getter/setter pair
viewBillRegister bool?
getter/setter pair
viewOutstandingBills bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited