AddressAndSurveyMasterData class

Constructors

AddressAndSurveyMasterData({bool? manageCityProvinces, bool? manageKhanDistrict, bool? manageSangkatCommune, bool? manageNationality, bool? manageReerBy, bool? setupAddressAndSurveyData})

Properties

hashCode int
The hash code for this object.
no setterinherited
manageCityProvinces bool?
getter/setter pair
manageKhanDistrict bool?
getter/setter pair
manageNationality bool?
getter/setter pair
manageReerBy bool?
getter/setter pair
manageSangkatCommune bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setupAddressAndSurveyData bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited