Bank class

Constructors

Bank({bool? spendMoney, bool? spendMoneyInterBankTransfer, bool? payBill, bool? receiveMoney, bool? recordPayment, bool? recordCashPurchase, bool? recordCashSale, Reconciliation? reconciliation, bool? viewBankRegister, bool? bankEnquiries, bool? applyPrepaymentBill, bool? applyPrepaymentSale})

Properties

applyPrepaymentBill bool?
getter/setter pair
applyPrepaymentSale bool?
getter/setter pair
bankEnquiries bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
payBill bool?
getter/setter pair
receiveMoney bool?
getter/setter pair
reconciliation Reconciliation?
getter/setter pair
recordCashPurchase bool?
getter/setter pair
recordCashSale bool?
getter/setter pair
recordPayment bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spendMoney bool?
getter/setter pair
spendMoneyInterBankTransfer bool?
getter/setter pair
viewBankRegister bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited