Items class

Constructors

Items({bool? manageItems, bool? manageItemGroups, bool? manageUnitsMeasures})

Properties

hashCode int
The hash code for this object.
no setterinherited
manageItemGroups bool?
getter/setter pair
manageItems bool?
getter/setter pair
manageUnitsMeasures bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited