MaintainProjects class

Constructors

MaintainProjects({bool? manageProjects, bool? manageProjectGroups, bool? setProjectStatus, bool? manageProjectAccessRights, bool? manageUserLogIn, bool? manageGroupAccessRights, bool? manageBackendSettings})

Properties

hashCode int
The hash code for this object.
no setterinherited
manageBackendSettings bool?
getter/setter pair
manageGroupAccessRights bool?
getter/setter pair
manageProjectAccessRights bool?
getter/setter pair
manageProjectGroups bool?
getter/setter pair
manageProjects bool?
getter/setter pair
manageUserLogIn bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setProjectStatus bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited