PayrollCalculation class

Constructors

PayrollCalculation({bool? runPayrollCalculation, bool? reviewPayroll, bool? approvePayroll, bool? finalizePayroll, bool? overridePayroll})

Properties

approvePayroll bool?
getter/setter pair
finalizePayroll bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
overridePayroll bool?
getter/setter pair
reviewPayroll bool?
getter/setter pair
runPayrollCalculation bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited