PayrollManagement class

Constructors

PayrollManagement({PayrollSystemSynce? payrollSystemSynce, PayrollCalculation? payrollCalculation, PayrollRuleAndPolicy? payrollRuleAndPolicy, MaintainPayrollRuleForPermission? maintainPayrollRuleForPermission, MaintainPayrollRuleForAttandance? maintainPayrollRuleForAttandance, MaintainPayrollRuleForBunus? maintainPayrollRuleForBunus})

Properties

hashCode int
The hash code for this object.
no setterinherited
maintainPayrollRuleForAttandance MaintainPayrollRuleForAttandance?
getter/setter pair
maintainPayrollRuleForBunus MaintainPayrollRuleForBunus?
getter/setter pair
maintainPayrollRuleForPermission MaintainPayrollRuleForPermission?
getter/setter pair
payrollCalculation PayrollCalculation?
getter/setter pair
payrollRuleAndPolicy PayrollRuleAndPolicy?
getter/setter pair
payrollSystemSynce PayrollSystemSynce?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited