Utility class

Constructors

Utility({bool? importFromExcel, bool? exportToExcel})

Properties

exportToExcel bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
importFromExcel bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited