ManageInventoryStockCountSession class
Constructors
- ManageInventoryStockCountSession({required int manageInventoryId, required dynamic employee, required Inventory inventory, required ManageStockCountSession manageStockCountSession})
Properties
- employee ↔ dynamic
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inventory ↔ Inventory
-
getter/setter pair
- manageInventoryId ↔ int
-
getter/setter pair
- manageStockCountSession ↔ ManageStockCountSession
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited