ManageInventoryStockCountSystem class

Constructors

ManageInventoryStockCountSystem({required int manageInventoryId, dynamic employee, Inventory? inventoryManagement, ManageStockCountSession? manageStockCountSession, DateTime? dateedit, DateTime? dateadd})
ManageInventoryStockCountSystem.fromJson(Map<String, dynamic> json)
factory

Properties

dateadd DateTime?
getter/setter pair
dateedit DateTime?
getter/setter pair
employee ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inventoryManagement Inventory?
getter/setter pair
manageInventoryId int
final
manageStockCountSession ManageStockCountSession?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited