ManageStockCountSystem class

Constructors

ManageStockCountSystem({required StockCountSystem stockCountSystem, required ICProject icProject, required int manageStockCountSystemId})

Properties

hashCode int
The hash code for this object.
no setterinherited
icProject ICProject
getter/setter pair
manageStockCountSystemId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stockCountSystem StockCountSystem
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited