StockCountRecord class

Constructors

StockCountRecord({required int stockCountRecordId, required ManageStockCountSession manageStockCountSession, required Inventory inventory, required double countedNumber, required dynamic countEmployee, required DateTime dateAdd, required DateTime dateEdit, required String description})

Properties

countedNumber double
getter/setter pair
countEmployee ↔ dynamic
getter/setter pair
dateAdd DateTime
getter/setter pair
dateEdit DateTime
getter/setter pair
description String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inventory Inventory
getter/setter pair
manageStockCountSession ManageStockCountSession
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stockCountRecordId int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited