Item class

Constructors

Item({String? newItemNumber, String? modelName, String? itemName1, String? itemName2, bool? inactive, String? reason, bool? stopPurchasing, int? itemTypeId, int? itemGroupId, String? itemBarcodeNo, int? costOfMethodId, DateTime? lastModifiedDate, String? purchaseDescriptionEn, String? purchaseDescriptionKH, double? unitCostRiel, double? unitCostUSD, double? salePriceRiel, double? salePriceUSD, double? wholeSalePriceRiel, double? wholeSalePriceUSD, double? otherCostRiel, double? otherCostUSD, int? costAccountId, String? saleDescriptionEn, String? saleDescriptionKH, int? salesAccountSaleAccountId, int? saleAccountId, double? minimumOrderQty, int? orderPeriodDay, double? recordPoint, int? defaultStockingWarehouse, double? qtyOnHand, String? equivalentUnitDescriptionEn, String? equivalentUnitDescriptionKH, bool? useDivideEquivalentUnit, bool? useBatch, bool? stockExpiry, bool? useSerial, bool? isConsignmentItem, bool? useBarcodeGenerateFromScale, bool? useQtyXEquivalentUnit, int? wipAccount, String? itemOID, double? height, double? lenght, double? width, double? grossWeight, double? convertedQty, bool? useCovertedQtyForReport, int? brandId, String? color, String? materials, int? gradeId, int? mainCategoryId, int? productCategoryId, int? subCategory1Id, int? subCategory2Id, int? subCategory3Id, int? warrantyPeriodYear, bool? useKit, bool? allowSaleUnderZero, bool? noDiscount, String? imagePath, String? invoiceItemItemName, int? unitDescriptionsId, int? purchaseTaxRateId, int? stockAccountId, int? saleTaxRateId, List<int>? subCategory5s, int? supplierId})
Item.fromJson(Map<String, dynamic> json)
factory

Properties

allowSaleUnderZero bool?
getter/setter pair
brandId int?
getter/setter pair
color String?
getter/setter pair
convertedQty double?
getter/setter pair
costAccountId int?
getter/setter pair
costOfMethodId int?
getter/setter pair
defaultStockingWarehouse int?
getter/setter pair
equivalentUnitDescriptionEn String?
getter/setter pair
equivalentUnitDescriptionKH String?
getter/setter pair
gradeId int?
getter/setter pair
grossWeight double?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height double?
getter/setter pair
imagePath String?
getter/setter pair
inactive bool?
getter/setter pair
invoiceItemItemName String?
getter/setter pair
isConsignmentItem bool?
getter/setter pair
itemBarcodeNo String?
getter/setter pair
itemGroupId int?
getter/setter pair
itemName1 String?
getter/setter pair
itemName2 String?
getter/setter pair
itemOID String?
getter/setter pair
itemTypeId int?
getter/setter pair
lastModifiedDate DateTime?
getter/setter pair
lenght double?
getter/setter pair
mainCategoryId int?
getter/setter pair
materials String?
getter/setter pair
minimumOrderQty double?
getter/setter pair
modelName String?
getter/setter pair
newItemNumber String?
getter/setter pair
noDiscount bool?
getter/setter pair
orderPeriodDay int?
getter/setter pair
otherCostRiel double?
getter/setter pair
otherCostUSD double?
getter/setter pair
productCategoryId int?
getter/setter pair
purchaseDescriptionEn String?
getter/setter pair
purchaseDescriptionKH String?
getter/setter pair
purchaseTaxRateId int?
getter/setter pair
qtyOnHand double?
getter/setter pair
reason String?
getter/setter pair
recordPoint double?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saleAccountId int?
getter/setter pair
saleDescriptionEn String?
getter/setter pair
saleDescriptionKH String?
getter/setter pair
salePriceRiel double?
getter/setter pair
salePriceUSD double?
getter/setter pair
salesAccountSaleAccountId int?
getter/setter pair
saleTaxRateId int?
getter/setter pair
stockAccountId int?
getter/setter pair
stockExpiry bool?
getter/setter pair
stopPurchasing bool?
getter/setter pair
subCategory1Id int?
getter/setter pair
subCategory2Id int?
getter/setter pair
subCategory3Id int?
getter/setter pair
subCategory5s List<int>?
getter/setter pair
supplierId int?
getter/setter pair
unitCostRiel double?
getter/setter pair
unitCostUSD double?
getter/setter pair
unitDescriptionsId int?
getter/setter pair
useBarcodeGenerateFromScale bool?
getter/setter pair
useBatch bool?
getter/setter pair
useCovertedQtyForReport bool?
getter/setter pair
useDivideEquivalentUnit bool?
getter/setter pair
useKit bool?
getter/setter pair
useQtyXEquivalentUnit bool?
getter/setter pair
useSerial bool?
getter/setter pair
warrantyPeriodYear int?
getter/setter pair
wholeSalePriceRiel double?
getter/setter pair
wholeSalePriceUSD double?
getter/setter pair
width double?
getter/setter pair
wipAccount int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited