Task class

Constructors

Task({required int taskId, String? taskName, String? taskDescription, DateTime? dateCreate, DateTime? dateEdit, TaskStatus? taskStatus, required TaskType taskType})

Properties

dateCreate DateTime?
getter/setter pair
dateEdit DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskDescription String?
getter/setter pair
taskId int
getter/setter pair
taskName String?
getter/setter pair
taskStatus TaskStatus?
getter/setter pair
taskType TaskType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited