TaskAssignment class
Constructors
- TaskAssignment({required int taskAssignmentId, Task? task, DelegationGroupRegister? delegationGroupRegister, DateTime? startDate, DateTime? dueDate, DateTime? completedDate, String? description, dynamic employeeAdd, dynamic employeeEdit, DateTime? dateAdd, DateTime? dateEdit, String? assignmentName, String? userAdd, String? userEdit})
Properties
- assignmentName ↔ String?
-
getter/setter pair
- completedDate ↔ DateTime?
-
getter/setter pair
- dateAdd ↔ DateTime?
-
getter/setter pair
- dateEdit ↔ DateTime?
-
getter/setter pair
- delegationGroupRegister ↔ DelegationGroupRegister?
-
getter/setter pair
- description ↔ String?
-
getter/setter pair
- dueDate ↔ DateTime?
-
getter/setter pair
- employeeAdd ↔ dynamic
-
getter/setter pair
- employeeEdit ↔ dynamic
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate ↔ DateTime?
-
getter/setter pair
- task ↔ Task?
-
getter/setter pair
- taskAssignmentId ↔ int
-
getter/setter pair
- userAdd ↔ String?
-
getter/setter pair
- userEdit ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited