TaskType class

Constructors

TaskType({required int taskTypeId, String? taskTypeName, String? taskTypeKh, String? description, bool? isActive, DateTime? dateAdd, DateTime? dateEdit, dynamic employeeAdd, dynamic employeeEdit, String? discriminator})

Properties

dateAdd DateTime?
getter/setter pair
dateEdit DateTime?
getter/setter pair
description String?
getter/setter pair
discriminator String?
getter/setter pair
employeeAdd ↔ dynamic
getter/setter pair
employeeEdit ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isActive bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskTypeId int
getter/setter pair
taskTypeKh String?
getter/setter pair
taskTypeName String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited