ApplicationUser class

Constructors

ApplicationUser({int? applicationUserId, String? fullName, String? name, String? email, String? password, bool? activatedCode, bool? isActive, DateTime? createdAt, DateTime? updatedAt, String? permissions, String? accessLevel, String? notes, String? groupAccessRight, String? token, int? accessRights, String? roleAccessRights, bool? settings, bool? generalLedger, bool? accountReceivable, bool? bank, bool? department, bool? accountPayable, bool? stock, bool? saleOrder, bool? purchaseOrder, bool? pos, bool? hrd, bool? warehousing, bool? service, bool? logistic, bool? task, bool? asset})
ApplicationUser.fromJson(Map<String, dynamic> json)
factory

Properties

accessLevel String?
getter/setter pair
accessRights int?
getter/setter pair
accountPayable bool?
getter/setter pair
accountReceivable bool?
getter/setter pair
activatedCode bool?
getter/setter pair
applicationUserId int?
getter/setter pair
asset bool?
getter/setter pair
bank bool?
getter/setter pair
createdAt DateTime?
getter/setter pair
department bool?
getter/setter pair
email String?
getter/setter pair
fullName String?
getter/setter pair
generalLedger bool?
getter/setter pair
groupAccessRight String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hrd bool?
getter/setter pair
isActive bool?
getter/setter pair
logistic bool?
getter/setter pair
name String?
getter/setter pair
notes String?
getter/setter pair
password String?
getter/setter pair
permissions String?
getter/setter pair
pos bool?
getter/setter pair
purchaseOrder bool?
getter/setter pair
roleAccessRights String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saleOrder bool?
getter/setter pair
service bool?
getter/setter pair
settings bool?
getter/setter pair
stock bool?
getter/setter pair
task bool?
getter/setter pair
token String?
getter/setter pair
updatedAt DateTime?
getter/setter pair
warehousing bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited