AssetAssignment class

Constructors

AssetAssignment({required int assignmentId, required int assetId, DateTime? assignmentDate, DateTime? returnDate, required int assignmentGroupId, required int departmentId, required int icEmployeeId, String? photo, String? projectName})
AssetAssignment.fromJson(Map<String, dynamic> json)
factory

Properties

assetId int
getter/setter pair
assignmentDate DateTime?
getter/setter pair
assignmentGroupId int
getter/setter pair
assignmentId int
getter/setter pair
departmentId int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
icEmployeeId int
getter/setter pair
photo String?
getter/setter pair
projectName String?
getter/setter pair
returnDate DateTime?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited