Asset class

Constructors

Asset({required int assetId, required String assetName, String? assetCode, required int assetCategoryId, String? assetCategoryName, required String departmentId, DateTime? purchaseDate, required double cost, required int statusId, String? assetStatusName, required int locationId, DateTime? warrantyExpiryDate, required int usefulLifeYears, required String depreciationMethod, String? deviceImage, String? deviceImagePreview, int? modelId, String? assetModelName, String? serial, String? assetTag, required int conditionId, String? conditionName, Uint8List? image, String? imageName, String? userAdd})
Asset.fromJson(Map<String, dynamic> json)
factory

Properties

assetCategoryId int
getter/setter pair
assetCategoryName String?
getter/setter pair
assetCode String?
getter/setter pair
assetId int
getter/setter pair
assetModelName String?
getter/setter pair
assetName String
getter/setter pair
assetStatusName String?
getter/setter pair
assetTag String?
getter/setter pair
conditionId int
getter/setter pair
conditionName String?
getter/setter pair
cost double
getter/setter pair
departmentId String
getter/setter pair
depreciationMethod String
getter/setter pair
deviceImage String?
getter/setter pair
deviceImagePreview String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
image Uint8List?
getter/setter pair
imageName String?
getter/setter pair
locationId int
getter/setter pair
modelId int?
getter/setter pair
purchaseDate DateTime?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serial String?
getter/setter pair
statusId int
getter/setter pair
usefulLifeYears int
getter/setter pair
userAdd String?
getter/setter pair
userEdit String?
getter/setter pair
warrantyExpiryDate DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited