AssetModel class

Constructors

AssetModel({required int modelId, String? modelName, String? description, String? dateAdded})
AssetModel.fromJson(Map<String, dynamic> json)
factory

Properties

dateAdded String?
getter/setter pair
description String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
modelId int
getter/setter pair
modelName String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited