AssetStatusByLocation class
Constructors
-
AssetStatusByLocation({required ICProject icProject, required List<
Asset> assets, required List<Map< assetStatus, required int assetCount})AssetStatus, dynamic> >
Properties
- assetCount → int
-
final
-
assets
→ List<
Asset> -
final
-
assetStatus
→ List<
Map< AssetStatus, dynamic> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icProject → ICProject
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited