ExternalApiClass class

Constructors

ExternalApiClass({required String licenseKeyId, required String licenseKey, required String externalWebApiTokenName, required String externalWebApiToken, required String employeeId})
ExternalApiClass.fromJson(Map<String, dynamic> json)
factory

Properties

employeeId String
final
externalWebApiToken String
final
externalWebApiTokenName String
final
hashCode int
The hash code for this object.
no setterinherited
licenseKey String
final
licenseKeyId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited