Department class

Constructors

Department({int? id, String? departmentName, String? departmentCode, String? description, int? statusId, String? userAdd, String? userEdit, DateTime? dateAdd, DateTime? dateEdit, String? ip, int? organizationId})
Department.fromJson(Map<String, dynamic> json)
factory

Properties

dateAdd DateTime?
final
dateEdit DateTime?
final
departmentCode String?
final
departmentName String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
id int?
final
ip String?
final
organizationId int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusId int?
final
userAdd String?
final
userEdit String?
final

Methods

copyWith({int? id, String? departmentName, String? departmentCode, String? description, int? statusId, String? userAdd, String? userEdit, DateTime? dateAdd, DateTime? dateEdit, String? ip, int? organizationId}) Department
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited