ICProject class

Constructors

ICProject({int? icProjectId, String? projectName, String? phoneNumber, String? address, String? image, DateTime? dateAdd, DateTime? dateEdit, String? ip, String? projectCode, String? lan, String? ion, String? userAdd, String? userEdit, String? scanSize, String? discriminator, int? statusId, required ProjectGroup projectGroup, required Organization organization, String? projectNameKh, String? projectCodeKh, String? phoneNumberKh, String? addressKh, String? ipKh, String? lanKh, String? ionKh, String? userAddKh, String? userEditKh, String? scanSizeKh, String? projectNameKhDescription, String? email})
ICProject.fromJson(Map<String, dynamic> json)
factory

Properties

address String?
final
addressKh String?
final
dateAdd DateTime?
final
dateEdit DateTime?
final
discriminator String?
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
icProjectId int?
final
image String?
final
ion String?
final
ionKh String?
final
ip String?
final
ipKh String?
final
lan String?
final
lanKh String?
final
organization Organization
final
phoneNumber String?
final
phoneNumberKh String?
final
projectCode String?
final
projectCodeKh String?
final
projectGroup ProjectGroup
final
projectName String?
final
projectNameKh String?
final
projectNameKhDescription String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanSize String?
final
scanSizeKh String?
final
statusId int?
final
userAdd String?
final
userAddKh String?
final
userEdit String?
final
userEditKh String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited