ProjectGroup class
Constructors
- ProjectGroup({int? projectGroupId, String? projectGroupName, String? projectGroupDescription})
-
ProjectGroup.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectGroupDescription → String?
-
final
- projectGroupId → int?
-
final
- projectGroupName → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited