IssuerGroup class
Constructors
- IssuerGroup({int? issuerGroupId, String? issuerGroupName, DateTime? dateAdd, DateTime? dateEdit, String? userAdd, String? userEdit})
-
IssuerGroup.fromJson(Map<
String, dynamic> json) -
factory
Properties
- dateAdd ↔ DateTime?
-
getter/setter pair
- dateEdit ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuerGroupId ↔ int?
-
getter/setter pair
- issuerGroupName ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userAdd ↔ String?
-
getter/setter pair
- userEdit ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited