CreateAnAccount class

Constructors

CreateAnAccount({String? username, String? email, RegisterType? registerType, String? password, String? confirmPassword})
CreateAnAccount.fromJson(Map<String, dynamic> json)
factory

Properties

confirmPassword String?
getter/setter pair
email String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
password String?
getter/setter pair
registerType RegisterType?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited