CustomerProcessPayment class
- Available extensions
Constructors
-
CustomerProcessPayment({List<
CustomerKhasCart> ? customerKhasCart, String? paymentMethodId, bool? success, String? message, SetUpPayment? setUpPayment}) -
CustomerProcessPayment.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
customerKhasCart
↔ List<
CustomerKhasCart> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String?
-
getter/setter pair
- paymentMethodId ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setUpPayment ↔ SetUpPayment?
-
getter/setter pair
- success ↔ bool?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited