MediaContent class

Available extensions

Constructors

MediaContent({required String fileName, required String fileExtension, required int fileSize, required List<int> fileData, required MediaType mediaType, required String mimeType})
MediaContent.fromJson(Map<String, dynamic> json)
factory

Properties

fileData List<int>
final
fileExtension String
final
fileName String
final
fileSize int
final
hashCode int
The hash code for this object.
no setterinherited
mediaType MediaType
final
mimeType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited