Notifications class

Available extensions

Constructors

Notifications({String? notificationId, NotificationType? notificationType, bool? isRead, String? notificationDate, String? notificationTitle, String? notificationImage})
Notifications.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isRead bool?
getter/setter pair
notificationDate String?
getter/setter pair
notificationId String?
getter/setter pair
notificationImage String?
getter/setter pair
notificationTitle String?
getter/setter pair
notificationType NotificationType?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited