StoreLocation class

Constructors

StoreLocation({String? storeId, String? storeName, String? storeAddress, String? storePhoneNumber, String? storeEmail, KhasUserCoordinate? khasUserCoordinate, List<MediaContent>? media})
StoreLocation.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
khasUserCoordinate KhasUserCoordinate?
getter/setter pair
media List<MediaContent>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeAddress String?
getter/setter pair
storeEmail String?
getter/setter pair
storeId String?
getter/setter pair
storeName String?
getter/setter pair
storePhoneNumber String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited