Position class

Constructors

Position({int? positionId, String? positionName, String? image, String? note, String? userAdd, String? dateAdd, String? userEdit, String? dateEdit, String? discriminator, String? positionNameKh})
Position.fromJson(Map<String, dynamic> json)
factory

Properties

dateAdd String?
getter/setter pair
dateEdit String?
getter/setter pair
discriminator String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
image String?
getter/setter pair
note String?
getter/setter pair
positionId int?
getter/setter pair
positionName String?
getter/setter pair
positionNameKh String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userAdd String?
getter/setter pair
userEdit String?
getter/setter pair

Methods

copyWith({int? positionId, String? positionName, String? image, String? note, String? userAdd, String? dateAdd, String? userEdit, String? dateEdit, String? discriminator, String? positionNameKh}) Position
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited