Shift class

Constructors

Shift({int? shiftId, String? shiftName, int? timeTableId, String? beginingInDate, int? cycleNum, int? cycleUnit, String? userAdd, String? dateAdd, String? userEdit, String? dateEdit, String? discriminator})
Shift.fromJson(Map<String, dynamic> json)
factory

Properties

beginingInDate String?
getter/setter pair
cycleNum int?
getter/setter pair
cycleUnit int?
getter/setter pair
dateAdd String?
getter/setter pair
dateEdit String?
getter/setter pair
discriminator String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shiftId int?
getter/setter pair
shiftName String?
getter/setter pair
timeTableId int?
getter/setter pair
userAdd String?
getter/setter pair
userEdit String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited