ChatState class

Constructors

ChatState({required List<Message_text> messages, required bool isLoading})
ChatState.initial()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isLoading bool
final
messages List<Message_text>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<Message_text>? messages, bool? isLoading}) ChatState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited