NotificationState class
Constructors
-
NotificationState({List<
Notifications> notifications = const []}) - NotificationState.initial()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
notifications
→ List<
Notifications> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< Notifications> ? notifications}) → NotificationState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited