TrackingState class

Constructors

TrackingState({required bool isTracking, required String? deviceId, required String? employeeId, required String sessionId, required String? permissions, required LocationSample? lastSample, required String status})
TrackingState.initial()
factory

Properties

deviceId String?
final
employeeId String?
final
hashCode int
The hash code for this object.
no setterinherited
isTracking bool
final
lastSample → LocationSample?
final
permissions String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
status String
final

Methods

copyWith({bool? isTracking, String? deviceId, String? employeeId, String? permissions, LocationSample? lastSample, String? status, String? sessionId}) TrackingState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited