AppState class

Constructors

AppState({required ChatState chatState, required ICPermissionState permissionState, required TrackingState tracking, required NotificationState notificationState, required AuthState authState})
AppState.initial()
factory

Properties

authState AuthState
final
chatState ChatState
final
hashCode int
The hash code for this object.
no setterinherited
notificationState NotificationState
final
permissionState ICPermissionState
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tracking TrackingState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited