PermissionSummary class
Constructors
- PermissionSummary({required String icEmployeeId, required int totalPermissions, required double totalAmount, required String firstPermissionDate, required String lastPermissionDate})
-
PermissionSummary.fromJson(Map<
String, dynamic> json) -
factory
Properties
- firstPermissionDate → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icEmployeeId → String
-
final
- lastPermissionDate → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalAmount → double
-
final
- totalPermissions → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited