Tasksservices class
Constructors
Properties
- channel ↔ ClientChannel
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskServiceClient ↔ TaskServiceClient
-
getter/setter pair
Methods
-
connect(
) → Future< void> -
GetTaskAssignment(
TaskAssignment taskassignment) → Future< List< TaskAssignment> > -
manageInventoryStockcountSystemService(
ManageInventoryStockCountSystem manageInventoryStockCount, String action) → Future< List< ManageInventoryStockCountSystem> > -
manageStockCountSystemMobile(
TaskAssignment taskassignment, String action) → Future< List< StockCountSystem> > -
manageStockCountSystemSession(
ICProject icproject, StockCountSystem stockcountSystem, String action) → Future< List< ManageStockCountSession> > -
manageStockTakeTasks(
TaskAssignment taskAssingment) → Future< List< StockTakeTask> > -
manageSubsectionStockTake(
List< ManageSubSectionStockTake> manageSubsectionstocktake, String action, ManageSubSectionStockTake manageSubSectionStockTakeDetail) → Future<List< ManageSubSectionStockTake> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited