MediaCacheService class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
cacheGrpcMedia(MediaItem item, FileCategory category, String conversationId)
→ Future<File>
-
Save a gRPC MediaItem to the appropriate cache folder
-
cacheGrpcMediaList(List<MediaItem> items, FileCategory category, String conversationId)
→ Future<Map<String, File>>
-
Cache a list of gRPC media files
-
downloadMediaListToDevice(List<MediaItem> items, FileCategory category, String conversationId, {OnMediaSaved? onMediaSaved})
→ Future<Map<String, File>>
-
Download and save media to persistent storage (not cache)
-
loadCachedMediaByConversation(FileCategory category, String conversationId)
→ Future<Map<String, File>>
-
Load cached media by conversation ID from cache folder