ChatService class
Constructors
Properties
- client ↔ ChatServiceClient
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getChatUserId(
String name) → Future< ChatUserList> -
getChatUserList(
) → Future< List< ChatUser> > -
getMessage(
String conversationId) → Future< List< Message> > -
getMessages(
String conversationId) → Future< List< Message_text> > -
getOrCreateConversation(
String currentUserId, String peerUserId) → Future< Conversation> -
getUnreadMessageCounts(
String userId) → Future< Map< String, int> > -
getUserConversation(
String userid) → Future< List< Conversation> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notificationChat(
String? names) → Future< ResponseStream< ChatNotification> > -
sendMessage(
{required String conversationId, required String senderId, required String content}) → Future< Message_text> -
sendTokenToServer(
String userid) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
uploadFile(
File file, String folder, String userid, String converstationId) → Future< MediaItem>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited