GRPCEmployeeClientService class
Properties
-
channel
↔ ClientChannel
-
getter/setter pair
-
employee
↔ dynamic
-
getter/setter pair
-
employeeServiceClient
↔ EmployeeServiceClient
-
getter/setter pair
-
EmployeesStub
↔ EmployeePermissionServiceClient
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
prefs
→ Future<SharedPreferences>
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
stub
↔ dynamic
-
getter/setter pair
Methods
-
connect()
→ Future<void>
-
-
createPermissions(dynamic CreateICPermissionRequest)
→ Future<CreateICPermissionResponse>
-
-
fetchPermissions(int icEmployeeId)
→ Future<List<PermissionRecord>>
-
-
fetchPermissionsDetails(String empId, {DateTime? startDate, DateTime? enddate})
→ Future<List<EmployeePermissionDetail>>
-
-
fetPermisionSummary({String? employeeId})
→ Future<List<EmployeePermissionSummary>>
-
-
getAllEmployees(String? employeeid, int? id)
→ Future<List>
-
-
getAllICPermissionProvider()
→ Future<List<ICPermissionProvider>>
-
-
getCurrentCheckStatus(int id)
→ Future<(bool, String)>
-
-
getEmployeePostion()
→ Future<List<EmployeePosition>>
-
-
getHRDProject()
→ Future<List<HRDProject>>
-
-
getPermissionGroupByEmployee(DateTime startDate, DateTime endDate, String? selectedBranch, String? selectedDepartment)
→ Future<PermissionsGroupByEmployeeResponse>
-
-
getProjectLocationResponse({String? office})
→ Future<GetProjectLocationResponse>
-
-
getProjectNameByEmployeeId(int icemployeeId)
→ Future<ProjectNameResponse>
-
-
insertAttendanceLog({String? ip, String? employeeId, String? bu, String? meterScan, String? hostName, String? state, String? EmployeeName})
→ Future<(bool, String)>
-
-
loadactivities(int icemployeeid)
→ Future<List<ICEmployeeActivity>>
-
-
loadPermission(dynamic ICPermissionQueryRequest)
→ Future<List<ICPermission>>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
searchEmployees(String nameController, String cardNumberController, String phoneNumberController, String emailController, String addressController, DateTime selectedJobDate, DateTime selectedResignedDate)
→ Future<List<HRDEmployee>>
-
-
shutdown()
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited