BatchingUploader class
Constructors
- BatchingUploader(GrpcClientFactory _factory, {int maxBatch = 100, Duration flushEvery = const Duration(seconds: 5), Duration maxBackoff = const Duration(minutes: 2)})
Properties
- flushEvery → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxBackoff → Duration
-
final
- maxBatch → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
enqueue(
LocationSample sample) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → Future< void> -
stop(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited