SampleBuilder class
Constructors
- SampleBuilder({required String deviceId, required String? employeeId, required String? sessionId})
Properties
- deviceId → String
-
final
- employeeId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
final
Methods
-
fromPosition(
Position p) → Future< LocationSample> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited