POS class
Constructors
- POS({POSManagement? posManagement, Reports? reports, Enquiries? enquiries, CompanyAndFinancial? companyAndFinancial, ClientsAndReceivables? clientsAndReceivables, TaxDepartmentReports? taxDepartmentReports})
Properties
- clientsAndReceivables ↔ ClientsAndReceivables?
-
getter/setter pair
- companyAndFinancial ↔ CompanyAndFinancial?
-
getter/setter pair
- enquiries ↔ Enquiries?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- posManagement ↔ POSManagement?
-
getter/setter pair
- reports ↔ Reports?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taxDepartmentReports ↔ TaxDepartmentReports?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited