Department class
Constructors
Properties
- dateAdd → String?
-
final
- dateEdit → String?
-
final
- departmentDescription → String?
-
final
- departmentId → int?
-
final
- departmentName → String?
-
final
- departmentNameKh → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userAdd → String?
-
final
- userEdit → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON map (for gRPC or API)
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited