ManageStockCountSession class
Constructors
- ManageStockCountSession({required int manageStockSessionId, String? manageStockCountSessionName, String? useradd, String? useredit, String? dateadd, String? dateedit, ManageStockCountSessionStatus? manageStockCountSessionStatus})
-
ManageStockCountSession.fromJson(Map<
String, dynamic> json) -
factory
Properties
- dateadd ↔ String?
-
getter/setter pair
- dateedit ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- manageStockCountSessionName ↔ String?
-
getter/setter pair
- manageStockCountSessionStatus ↔ ManageStockCountSessionStatus?
-
getter/setter pair
- manageStockSessionId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useradd ↔ String?
-
getter/setter pair
- useredit ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited