ManageSubSectionStockTake class
Constructors
-
ManageSubSectionStockTake({required int manageSubSectionStockTakeId, ManageStockCountSession? manageStockCountSession, String? manageSubSectionStockTakeName, DateTime? dateAdd, DateTime? dateEdit, dynamic icEmployeeDTO, required List<
ManageSubSectionStockTakeInventory> manageSubSectionStockTakeInventory}) -
ManageSubSectionStockTake.fromJson(Map<
String, dynamic> json) -
factory
Properties
- dateAdd ↔ DateTime?
-
getter/setter pair
- dateEdit ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icEmployeeDTO ↔ dynamic
-
getter/setter pair
- manageStockCountSession ↔ ManageStockCountSession?
-
getter/setter pair
- manageSubSectionStockTakeId → int
-
final
-
manageSubSectionStockTakeInventory
→ List<
ManageSubSectionStockTakeInventory> -
final
- manageSubSectionStockTakeName ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ManageStockCountSession? manageStockCountSession, String? manageSubSectionStockTakeName, List< ManageSubSectionStockTakeInventory> ? manageSubSectionStockTakeInventory, DateTime? dateAdd, DateTime? dateEdit, dynamic icEmployeeDTO}) → ManageSubSectionStockTake -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited