ManageSubSectionStockTakeInventory class
Constructors
- ManageSubSectionStockTakeInventory({required int manageSubSectionStockTakeInventoryId, required Inventory inventoryManagement, DateTime? dateAdd, DateTime? dateEdit, required double qtyCounted, bool isSubmitted = false})
-
ManageSubSectionStockTakeInventory.fromJson(Map<
String, dynamic> json) -
factory
Properties
- dateAdd ↔ DateTime?
-
getter/setter pair
- dateEdit ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inventoryManagement → Inventory
-
final
- isSubmitted ↔ bool
-
getter/setter pair
- manageSubSectionStockTakeInventoryId → int
-
final
- qtyCounted → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{DateTime? dateAdd, DateTime? dateEdit, bool? isSubmitted}) → ManageSubSectionStockTakeInventory -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited