StockCountRecordManagement class
Constructors
- StockCountRecordManagement(int stockCountRecordId, ManageStockCountSystem manageStockCountSystem, Inventory inventory, dynamic icemployee, double countNumber, DateTime dateadd, DateTime dateedit)
Properties
- countNumber → double
-
final
- dateadd → DateTime
-
final
- dateedit → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icemployee → dynamic
-
final
- inventory → Inventory
-
final
- manageStockCountSystem → ManageStockCountSystem
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stockCountRecordId → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited