StockCountSystem class
Constructors
- StockCountSystem({required int stockCountSystemId, StockCountSystemSession? stockCountSystemSession, TaskType? taskType, String? taskTypeName, String? taskTypeKh, String? description, bool? isActive, DateTime? dateAdd, DateTime? dateEdit, dynamic employeeAdd, dynamic employeeEdit})
Properties
- dateAdd → DateTime?
-
final
- dateEdit → DateTime?
-
final
- description → String?
-
final
- employeeAdd → dynamic
-
final
- employeeEdit → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stockCountSystemId → int
-
final
- stockCountSystemSession → StockCountSystemSession?
-
final
- taskType → TaskType?
-
final
- taskTypeKh → String?
-
final
- taskTypeName → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited