StockTakeTask class
Constructors
-
StockTakeTask({required int stocktakeid, required Task task, required List<
StockCountTaskPriority> stockCountTaskPriority})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stockCountTaskPriority
→ List<
StockCountTaskPriority> -
final
- stocktakeid → int
-
final
- task → Task
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited