ProjectAccessRight class
Constructors
- ProjectAccessRight({bool? bank, bool? accountPayable, bool? accountReceivable, bool? asset, bool? department, bool? settings, bool? generalLedger, bool? hrd, bool? logistic, bool? purchaseOrder, bool? stock, bool? warehousing, bool? tasks, bool? saleorder, bool? pos, bool? service})
-
ProjectAccessRight.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accountPayable ↔ bool?
-
getter/setter pair
- accountReceivable ↔ bool?
-
getter/setter pair
- asset ↔ bool?
-
getter/setter pair
- bank ↔ bool?
-
getter/setter pair
- department ↔ bool?
-
getter/setter pair
- generalLedger ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hrd ↔ bool?
-
getter/setter pair
- logistic ↔ bool?
-
getter/setter pair
- pos ↔ bool?
-
getter/setter pair
- purchaseOrder ↔ bool?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saleorder ↔ bool?
-
getter/setter pair
- service ↔ bool?
-
getter/setter pair
- settings ↔ bool?
-
getter/setter pair
- stock ↔ bool?
-
getter/setter pair
- tasks ↔ bool?
-
getter/setter pair
- warehousing ↔ bool?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited